@@ -21,22 +21,30 @@ load_dotenv()
 
 def setEnviron(parameter, *args, **kwargs):
     storage = kwargs.get('storage', False)
-
+    
     try:
         msgBody = json.loads(parameter)
     except:
         msgBody = parameter
 
     try:
-        Api_Key = os.environ["APIKey"]
-        VallarisServer = os.environ["VallarisServer"]
-
-    except:
         GP_API_FEATURES_HOST = os.environ.get('GP_API_FEATURES_HOST', 'https://v2k-dev.vallarismaps.com/core/api/features')
         url = GP_API_FEATURES_HOST.split("/")[-4]
-
         Api_Key = msgBody["API-Key"]
-        VallarisServer = "https://" + url
+        VallarisServer = GP_API_FEATURES_HOST
+
+        if 'APIKey' in os.environ:
+            del os.environ['APIKey']
+        
+        if 'VallarisServer' in os.environ:
+            del os.environ['VallarisServer']
+        
+        os.environ["APIKey"] = Api_Key
+        os.environ["VallarisServer"] = VallarisServer
+
+    except:
+        Api_Key = os.environ["APIKey"]
+        VallarisServer = os.environ["VallarisServer"]
 
     return [Api_Key, VallarisServer]
 
@@ -386,7 +394,11 @@ def ProcessSuccess(storage, parameter, msg, file_final):
 
     msgOption = msgBody
     _output = msgOption['process']['outputs'][0]['format']
-    order = 1
+    
+    try :
+        order = msgOption['process']['order']
+    except :
+        order = 1
 
     if "application/json" in _output:
         _output = 'json'
